@@ -27,7 +27,6 @@
 #include <array>
 
 // Qt
-#include <QMessageBox>
 #include <QMouseEvent>
 #include <QPainter>
 #include <QStandardPaths>
@@ -35,6 +34,7 @@
 
 // KDE
 #include <KLocalizedString>
+#include <KMessageBox>
 
 // KShisen
 #include "debug.h"
@@ -98,16 +98,18 @@ Board::Board(QWidget * parent)
 void Board::loadSettings()
 {
     if (!loadTileset(Prefs::tileSet())) {
-        QMessageBox::critical(this,
-                              i18n("Error Loading Tiles"),
-                              i18nc("%1 is a path to a tileset file", "An error occurred when loading the tileset. %1 and the default tileset have been tried.\nPlease install the KMahjongg library.", Prefs::tileSet()));
+        KMessageBox::error(this
+                           , i18nc("%1 is a path to a tileset file", "An error occurred when loading the tileset. %1 and the default tileset have been tried.\nPlease install the KMahjongg library.", Prefs::tileSet())
+                           , i18n("Error Loading Tiles")
+                          );
     }
 
     // Load background
     if (!loadBackground(Prefs::background())) {
-        QMessageBox::critical(this,
-                              i18n("Error Loading Background"),
-                              i18nc("%1 is a path to a background image file", "An error occurred when loading the background. %1 and the default background have been tried.\nPlease install the KMahjongg library.", Prefs::background()));
+        KMessageBox::error(this
+                           , i18nc("%1 is a path to a background image file", "An error occurred when loading the background. %1 and the default background have been tried.\nPlease install the KMahjongg library.", Prefs::background())
+                           , i18n("Error Loading Background")
+                          );
     }
 
     // There are tile sets, that have only one tile for e.g. the flowers group.
@@ -691,7 +693,7 @@ void Board::paintEvent(QPaintEvent * e)
     if (m_paintPossibleMoves) {
         p.setPen(QPen(QColor("blue"), lineWidth()));
         // paint all possible moves
-        foreach (auto const move, m_possibleMoves) {
+        for (auto const &move : qAsConst(m_possibleMoves)) {
             auto pt1 = move.path().cbegin();
             auto pt2 = pt1 + 1;
             while (pt2 != move.path().cend()) {
@@ -894,7 +896,7 @@ void Board::marked(TilePos const & tilePos)
 {
     if (field(tilePos) == EMPTY) { // click on empty space on the board
         if (m_possibleMoves.size() > 1) { // if the click is on any of the current possible moves, make that move
-            foreach (auto move, m_possibleMoves) {
+            for (auto move : qAsConst(m_possibleMoves)) {
                 if (move.isInPath(tilePos)) {
                     performMove(move);
                     emit selectATile();
@@ -932,7 +934,7 @@ void Board::marked(TilePos const & tilePos)
     }
     if (m_possibleMoves.size() > 1) { // if the click is on any of the current possible moves, make that move
 
-        foreach (auto move, m_possibleMoves) {
+        for (auto move : qAsConst(m_possibleMoves)) {
             if (move.isInPath(tilePos)) {
                 performMove(move);
                 emit selectATile();
@@ -955,7 +957,7 @@ void Board::marked(TilePos const & tilePos)
     if (findPath(TilePos(m_markX, m_markY), tilePos, m_possibleMoves) > 0) {
         if (m_possibleMoves.size() > 1) {
             auto withSlide = 0;
-            foreach (auto const move, m_possibleMoves) {
+            for (auto const &move : qAsConst(m_possibleMoves)) {
                 move.Debug();
                 if (move.hasSlide()) {
                     ++withSlide;
